==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hr_HR\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linija"

, "Caller Id"
: "Id pozivatelja"

, "Start"
: "Start"

, "Connected"
: "Spojen"

, "Disconnected"
: "Isključen"

, "Duration"
: "Trajanje"

, "Ringing"
: "Zvonjenje"

, "Direction"
: "Smjer"

, "Source"
: "Izvor"

, "Destination"
: "Odredište"

, "Phone"
: ""

, "Phones"
: "Telefoni"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Broj"

, "Cancel"
: "Otkazi"

, "Dial"
: "Birati"

, "Error"
: "Greška"

, "Not possible to dial."
: "Nije moguće birati."

, "Edit phone settings"
: "Uredi postavke telefona"

, "Dial number"
: "Birajte broj"

, "Initiate a new outgoing call"
: "Pokrenite novi odlazni poziv"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Pozovi kontakt"

, "Work"
: "radni"

, "Home"
: "kućni"

, "Cell"
: "Mobitel"

, "Cell private"
: "Privatni mobitel"

, "Incoming call"
: "Dolazni poziv"

, "Outgoing call"
: "Odlazni poziv"

, "unknown number"
: "nepoznati broj"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Dolazni poziv"

, "Outgoing call"
: "Odlazni poziv"

, "unknown number"
: "nepoznati broj"

, "Phone"
: ""

, "Line"
: "Linija"

, "Number"
: "Broj"

, "Cancel"
: "Otkazi"

, "Dial"
: "Birati"

, "Error"
: "Greška"

, "Not possible to dial."
: "Nije moguće birati."

, "Call contact"
: "Pozovi kontakt"

, "Work"
: "radni"

, "Home"
: "kućni"

, "Cell"
: "Mobitel"

, "Cell private"
: "Privatni mobitel"

, "Edit phone settings"
: "Uredi postavke telefona"

, "Dial number"
: "Birajte broj"

, "Initiate a new outgoing call"
: "Pokrenite novi odlazni poziv"

, "Phones"
: "Telefoni"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Id pozivatelja"

, "Start"
: "Start"

, "Connected"
: "Spojen"

, "Disconnected"
: "Isključen"

, "Duration"
: "Trajanje"

, "Ringing"
: "Zvonjenje"

, "Direction"
: "Smjer"

, "Source"
: "Izvor"

, "Destination"
: "Odredište"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
